package com.incubator.game.util;

import com.incubator.game.player.Player;
import com.incubator.game.room.JDGDRoom;
import com.incubator.game.room.Room;

import java.util.*;

/**
 * 消息工具类
 */
public final class ProtoUtil {

    /**
     * 玩家信息转消息
     *
     * @param player
     * @return
     */
    public static Map<String, Object> playerInfoToMessage(Player player) {
        Map<String, Object> data = new HashMap<>();
        data.put("id", player.getId());
        data.put("name", player.data.name);
        data.put("avatar", "https://img95.699pic.com/element/40109/0194.png_300.png");
        data.put("sex", player.data.sex);
        data.put("exp", player.data.exp);
        data.put("vipLevel", player.data.vipLevel);
        data.put("masterScore", player.data.masterScore);
        data.put("masterScoreLevel", player.data.masterScoreLevel);
        data.put("gold", player.data.gold);
        data.put("diamond", player.data.diamond);
        data.put("startTimeVip", player.data.startTimeVip);
        data.put("endTimeVip", player.data.endTimeVip);
        data.put("gps", player.data.gps);
        data.put("gpsAddr", player.data.gpsAddr);
        data.put("foca", player.data.foca);
        data.put("ranking", player.data.ranking);
        data.put("figureId", player.data.figureId);
        data.put("realName", player.data.realName);
        data.put("phoneNum", player.data.phoneNum);
        data.put("idCard", player.data.idCard);
        data.put("friendMasterNum", player.data.friendMasterNum);
        data.put("friendMasterRate", player.data.friendMasterRate);
        data.put("tradPoints", player.data.tradPoints);
        data.put("tradPointsRate", player.data.tradPointsRate);
        data.put("tradMatchNum", player.data.tradMatchNum);
        data.put("tradMatchRate", player.data.tradMatchRate);
        data.put("noReshNum", player.data.noReshNum);
        data.put("noReshRate", player.data.noReshRate);
        return data;
    }

    /**
     * 房间信息转消息
     *
     * @param room
     * @param player 本人
     * @param opPlayer 当前操作玩家
     * @return
     */
    public static Map<String, Object> roomToMessage(Room room, Player player, Player opPlayer) {
        Map<String, Object> data = new HashMap<>();
        data.put("roomId", room.roomId);
        data.put("type", room.type);
        data.put("ownerId", room.ownerId);
        data.put("state", room.state);
        data.put("time", room.time);
        // todo 后面这里写法要调整
        if (room.type == 1) {
            data.put("maxRound", ((JDGDRoom) room).data.maxRound);
            data.put("curRound", ((JDGDRoom) room).data.curRound);
            data.put("zhuangPos", ((JDGDRoom) room).data.zhuangPos);
            // 当前级牌点数
            data.put("curLevelPoint", ((JDGDRoom) room).data.curLevelPoint);
            data.put("opId", opPlayer != null ? opPlayer.getId() : "");
            data.put("opPos", opPlayer != null ? opPlayer.data.pos : -1);
            data.put("curDiscardList", ((JDGDRoom) room).data.curDisCardList);
            data.put("curDisCardType", ((JDGDRoom) room).data.curDisCardType);
            data.put("curDiscardPlayer", ((JDGDRoom) room).data.disCardPlayer != null ? ((JDGDRoom) room).data.disCardPlayer.getId() : "");
            data.put("curDiscardSex", ((JDGDRoom) room).data.disCardPlayer != null ? ((JDGDRoom) room).data.disCardPlayer.data.sex : 0);
            data.put("myInfo", playerRoomToMessage(room, player, true));
            List<Map<String, Object>> otherInfo = new ArrayList<>();
            for (Player tmPlayer : ((JDGDRoom) room).data.playerMap.values()) {
                if (tmPlayer != null && !Objects.equals(tmPlayer.getId(), player.getId())) {
                    otherInfo.add(playerRoomToMessage(room, tmPlayer, false));
                }
            }
            data.put("otherInfo", otherInfo);
        }
        return data;
    }

    /**
     * 玩家信息转消息
     *
     * @param room
     * @param player 玩家
     * @param flag 是否本人
     * @return
     */
    public static Map<String, Object> playerRoomToMessage(Room room, Player player, boolean flag) {
        // todo 后面这里写法要调整
        Map<String, Object> data = new HashMap<>();
        data.put("id", player.getId());
        data.put("name", player.data.name);
        data.put("avatar", "https://img95.699pic.com/element/40109/0194.png_300.png");
        data.put("sex", player.data.sex);
        data.put("pos", player.data.pos);
        data.put("state", player.data.state);
        data.put("isAuto", player.data.isAuto);
        // 级数显示 [我方级数, 对方级数]
        data.put("levelPointView", player.data.levelPointView);
        // 队友Id
        data.put("teammateId", player.data.teammateId);
        Map<String, Object> cardInfo = new HashMap<>();
        cardInfo.put("remainCards", flag? player.data.remainCards : "");
        cardInfo.put("remainCardsNum", player.data.remainCards.length);
        data.put("cardInfo", cardInfo);
        return data;
    }

}
